//[mahjong-utils](../../../../index.md)/[mahjongutils.models](../../index.md)/[Tile](../index.md)/[Companion](index.md)/[get](get.md)

# get

[common]\
operator fun [get](get.md)(code: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [Tile](../index.md)

根据编号获取牌

[common]\
fun [get](get.md)(type: [TileType](../../-tile-type/index.md), num: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [Tile](../index.md)

根据种类和数字获取牌

[common]\
operator fun [get](get.md)(text: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)): [Tile](../index.md)

根据文本获取牌
